import { DateRange } from "../dateRange";
import { DateTime } from "luxon";
/**
 * Options for the `chunkMonthExtended` function.
 */
interface ChunkMonthExtendedOptions {
    /**
     * If set to `true`, the resulting chunks will have `null` values for dates
     * that do not belong to the same month as the reference date.
     * If set to `false` or not provided, the resulting chunks will only contain
     * valid `DateTime` objects and no `null` values.
     */
    nullNextPrevDates?: boolean;
}
/**
 * Splits the given `DateRange` into chunks of `DateTime` arrays, each containing
 * a week's worth of dates. Optionally, the chunks can be extended with `null`
 * values for dates that do not belong to the same month as the reference date.
 *
 * @param dateRange - The `DateRange` to be split into chunks.
 * @param options - (Optional) The {@link ChunkMonthExtendedOptions} to customize the chunking behavior.
 * @returns An array of arrays containing the chunks of `DateTime` objects.
 * If `options.nullNextPrevDates` is `true`, the chunks may contain `null` values for dates
 * that do not belong to the same month as the reference date.
 * If `options.nullNextPrevDates` is `false` or not provided, the chunks will only contain
 * valid `DateTime` objects and no `null` values.
 *
 * @throws {MissingArgumentError}
 * When `dateRange` is not provided.
 * @throws {Error}
 * When `dateRange` is not an instance of `DateRange` or has an invalid range type.
 * @throws {InvalidParameterError}
 * When `options.nullNextPrevDates` is provided but not a boolean value.
 *
 * @example
 * // Example: Splitting the current month into chunks with `null` values for dates outside the month.
 * const dateRange = new DateRange().getMonthExtended();
 * // dateRange is a `DateRange` for the current month, extended to full weeks.
 *
 * const result = chunkMonthExtended(dateRange, { nullNextPrevDates: true });
 * // result will be an array of arrays, each containing a week's worth of dates,
 * // with `null` values for dates that do not belong to the same month as the reference date.
 */
export declare function chunkMonthExtended(dateRange: DateRange, options?: ChunkMonthExtendedOptions & {
    nullNextPrevDates: false;
}): DateTime[][];
export declare function chunkMonthExtended(dateRange: DateRange, options: ChunkMonthExtendedOptions & {
    nullNextPrevDates: true;
}): (DateTime | null)[][];
export declare function chunkMonthExtended(dateRange: DateRange, options?: ChunkMonthExtendedOptions): (DateTime | null)[][] | DateTime[][];
export {};
